/************************************************************************/
/*		aPCI-8133 Device Driver for Windows 9x/NT						*/
/*																		*/
/*			apci8133.h	-	Win32 interface definition					*/
/*			date		-	1999/05/31									*/
/************************************************************************/

#if !defined( APCI8133_H )
#define	APCI8133_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI8133_SUCCESS				0	/* Successfully proccessed */
#define	APCI8133_ERR_SYSTEM				1	/* Call GetLastError() */
#define	APCI8133_ERR_NO_DEVICE			2	/* No card */
#define	APCI8133_ERR_IN_USE				3	/* Device is in use */
#define	APCI8133_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI8133_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI8133_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI8133_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI8133_ERR_NO_CREATE			8	/* No created device */
#define APCI8133_ERR_BAD_COMMAND		9	/* Bad command */
#define	APCI8133_ERR_INVALID_MODE		10	/* Invalid mode */

/*==========================================*/
/*	aPCI-8133 card's relative port address	*/
/*==========================================*/
#define	APCI8133_PORT_1		0
#define	APCI8133_PORT_2		1
#define	APCI8133_PORT_3		2
#define	APCI8133_PORT_4		3
#define	APCI8133_PORT_5		4
#define	APCI8133_PORT_6		5
#define	APCI8133_PORT_7		6
#define	APCI8133_PORT_8		7

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI8133_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI8133_MAX_PORTS	8			/* Maximum number of user ports */

										/* default search */
#define	APCI8133_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI8133_BOARD_ID	0x8133		/* pci bus device id */
#define	APCI8133_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI8133_DEVICE_ID	( ( DWORD )APCI8133_BOARD_ID\
							| ( ( DWORD )APCI8133_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI8133_MAX_MEM	9			/* number of memory windows */
#define	APCI8133_MAX_IO		20			/* number of i/o windows */
#define	APCI8133_MAX_DMA	7			/* number of dmas */

typedef	struct	_APCI8133RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI8133_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI8133_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI8133_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI8133_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI8133_MAX_IO];	/* I/O port length */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI8133_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI8133_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI8133RESOURCE, *PAPCI8133R;

#if !defined( APCI8133_DRIVER )
#define	APCI8133_API

#if !defined( APCI8133_DLL )
	#define APCI8133LIB_API	extern __declspec( dllimport )
#else
	#define APCI8133LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI8133LIB_API BOOL	WINAPI	Apci8133GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI8133LIB_API BOOL	WINAPI	Apci8133Create( PWORD pwLogSlot );
APCI8133LIB_API BOOL	WINAPI	Apci8133Close( WORD wLogSlot );
APCI8133LIB_API BOOL	WINAPI	Apci8133GetResource( WORD wLogSlot, PAPCI8133R pres );
APCI8133LIB_API BOOL	WINAPI	Apci8133OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI8133LIB_API DWORD	WINAPI	Apci8133GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI8133_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI8133_H ) */

/**/